# Core VPScommacc

## file.py
* Отсортировать csv-файл по определенной колонке
* Записать одну строку в csv-файл
* Записать несколько строк в csv-файл

## mix.py
* Вычесть из первого списка элементы второго списка
* Найти элементы присутствующие в обоих списках

## path.py
* Получить все файлы из директории с полными путями (рекурсивно или нет)
* Получить путь к директории относительно текущей
* Получить путь к текущей директории


## regexp.py
* Очистить строку от всех html-тегов
* Получить все символы из текста (кириллица или латиница)
* Получить все цифры из текста


## time.py
* Получить порядковый номер дня недели
* Получить UNIX-метку
* Получить текущие дату и время
* Дата и время в русском формате
* Дата и время в английском формате
